@@ -3,7 +3,7 @@
 import sys
 
 from .compression import decompress
-from .exceptions import reraise, MessageStateError
+from .exceptions import MessageStateError, reraise
 from .serialization import loads
 from .utils.functional import dictfilter
 
@@ -126,6 +126,10 @@ class Message:
     def ack_log_error(self, logger, errors, multiple=False):
         try:
             self.ack(multiple=multiple)
+        except BrokenPipeError as exc:
+            logger.critical("Couldn't ack %r, reason:%r",
+                            self.delivery_tag, exc, exc_info=True)
+            raise
         except errors as exc:
             logger.critical("Couldn't ack %r, reason:%r",
                             self.delivery_tag, exc, exc_info=True)
